==> jc-1.4.0.tar.gz: java/awt/event/KeyAdapter.h <==
// public abstract class java.awt.event.KeyAdapter

// class file dependencies
// @dep_class b920d196013f4f61 java_awt_event_KeyAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_event_KeyAdapter_H_
#define _JC_java_awt_event_KeyAdapter_H_

// Forward structure declarations
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_KeyAdapter$sub_refs	_jc_java_awt_event_KeyAdapter$sub_refs;
typedef struct _jc_java_awt_event_KeyAdapter$sub_nonrefs	_jc_java_awt_event_KeyAdapter$sub_nonrefs;
typedef struct _jc_java_awt_event_KeyAdapter$refs	_jc_java_awt_event_KeyAdapter$refs;
typedef struct _jc_java_awt_event_KeyAdapter$nonrefs	_jc_java_awt_event_KeyAdapter$nonrefs;
typedef struct _jc_java_awt_event_KeyAdapter$object	_jc_java_awt_event_KeyAdapter$object;

typedef const struct _jc_java_awt_event_KeyAdapter$vmethods	_jc_java_awt_event_KeyAdapter$vmethods;
typedef const struct _jc_java_awt_event_KeyAdapter$vtable	_jc_java_awt_event_KeyAdapter$vtable;
typedef const struct _jc_java_awt_event_KeyAdapter$vtype	_jc_java_awt_event_KeyAdapter$vtype;

// Constructors
extern void _jc_java_awt_event_KeyAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_event_KeyAdapter$object *);

// Virtual methods
extern void _jc_java_awt_event_KeyAdapter$method$keyPressed$d7fe1c88a82640ee(_jc_env *, struct _jc_java_awt_event_KeyAdapter$object *, struct _jc_java_awt_event_KeyEvent$object *);
extern void _jc_java_awt_event_KeyAdapter$method$keyReleased$c1315bcf69bed992(_jc_env *, struct _jc_java_awt_event_KeyAdapter$object *, struct _jc_java_awt_event_KeyEvent$object *);
extern void _jc_java_awt_event_KeyAdapter$method$keyTyped$f9f3a1945675f073(_jc_env *, struct _jc_java_awt_event_KeyAdapter$object *, struct _jc_java_awt_event_KeyEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_KeyAdapter$method_info$keyPressed$d7fe1c88a82640ee;
extern _jc_method _jc_java_awt_event_KeyAdapter$method_info$keyReleased$c1315bcf69bed992;
extern _jc_method _jc_java_awt_event_KeyAdapter$method_info$keyTyped$f9f3a1945675f073;

// Virtual methods structure
struct _jc_java_awt_event_KeyAdapter$vmethods {
	void	(*keyPressed$d7fe1c88a82640ee)(_jc_env *, struct _jc_java_awt_event_KeyAdapter$object *, struct _jc_java_awt_event_KeyEvent$object *);
	void	(*keyReleased$c1315bcf69bed992)(_jc_env *, struct _jc_java_awt_event_KeyAdapter$object *, struct _jc_java_awt_event_KeyEvent$object *);
	void	(*keyTyped$f9f3a1945675f073)(_jc_env *, struct _jc_java_awt_event_KeyAdapter$object *, struct _jc_java_awt_event_KeyEvent$object *);
};

// Vtable
struct _jc_java_awt_event_KeyAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_KeyAdapter$vmethods	java_awt_event_KeyAdapter;
};

// Vtype
struct _jc_java_awt_event_KeyAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_event_KeyAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_KeyAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_KeyAdapter$refs {
    _jc_java_awt_event_KeyAdapter$sub_refs	java_awt_event_KeyAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_KeyAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_KeyAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_KeyAdapter$sub_nonrefs	java_awt_event_KeyAdapter;
};

// Object instance structure
struct _jc_java_awt_event_KeyAdapter$object {
	_jc_java_awt_event_KeyAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_KeyAdapter$vtype	*vtype;
	_jc_java_awt_event_KeyAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_KeyAdapter$vtype _jc_java_awt_event_KeyAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_KeyAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_KeyAdapter$class_object;

#endif	/* _JC_java_awt_event_KeyAdapter_H_ */

==> jc-1.4.6.tar.gz: java/awt/event/KeyAdapter.h <==
// public abstract class java.awt.event.KeyAdapter

// class file dependencies
// @dep_class b920d196013f4f61 java_awt_event_KeyAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_event_KeyAdapter_H_
#define _JC_java_awt_event_KeyAdapter_H_

// Forward structure declarations
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_KeyAdapter$sub_refs	_jc_java_awt_event_KeyAdapter$sub_refs;
typedef struct _jc_java_awt_event_KeyAdapter$sub_nonrefs	_jc_java_awt_event_KeyAdapter$sub_nonrefs;
typedef struct _jc_java_awt_event_KeyAdapter$refs	_jc_java_awt_event_KeyAdapter$refs;
typedef struct _jc_java_awt_event_KeyAdapter$nonrefs	_jc_java_awt_event_KeyAdapter$nonrefs;
typedef struct _jc_java_awt_event_KeyAdapter$object	_jc_java_awt_event_KeyAdapter$object;

typedef const struct _jc_java_awt_event_KeyAdapter$vmethods	_jc_java_awt_event_KeyAdapter$vmethods;
typedef const struct _jc_java_awt_event_KeyAdapter$vtable	_jc_java_awt_event_KeyAdapter$vtable;
typedef const struct _jc_java_awt_event_KeyAdapter$vtype	_jc_java_awt_event_KeyAdapter$vtype;

// Constructors
extern void _jc_java_awt_event_KeyAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_event_KeyAdapter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_event_KeyAdapter$method$keyPressed$d7fe1c88a82640ee(_jc_env *, struct _jc_java_awt_event_KeyAdapter$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_KeyAdapter$method$keyReleased$c1315bcf69bed992(_jc_env *, struct _jc_java_awt_event_KeyAdapter$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_KeyAdapter$method$keyTyped$f9f3a1945675f073(_jc_env *, struct _jc_java_awt_event_KeyAdapter$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_KeyAdapter$method_info$keyPressed$d7fe1c88a82640ee;
extern _jc_method _jc_java_awt_event_KeyAdapter$method_info$keyReleased$c1315bcf69bed992;
extern _jc_method _jc_java_awt_event_KeyAdapter$method_info$keyTyped$f9f3a1945675f073;

// Virtual methods structure
struct _jc_java_awt_event_KeyAdapter$vmethods {
	void	(*keyPressed$d7fe1c88a82640ee)(_jc_env *, struct _jc_java_awt_event_KeyAdapter$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
	void	(*keyReleased$c1315bcf69bed992)(_jc_env *, struct _jc_java_awt_event_KeyAdapter$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
	void	(*keyTyped$f9f3a1945675f073)(_jc_env *, struct _jc_java_awt_event_KeyAdapter$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_KeyAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_KeyAdapter$vmethods	java_awt_event_KeyAdapter;
};

// Vtype
struct _jc_java_awt_event_KeyAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_event_KeyAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_KeyAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_KeyAdapter$refs {
    _jc_java_awt_event_KeyAdapter$sub_refs	java_awt_event_KeyAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_KeyAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_KeyAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_KeyAdapter$sub_nonrefs	java_awt_event_KeyAdapter;
};

// Object instance structure
struct _jc_java_awt_event_KeyAdapter$object {
	_jc_java_awt_event_KeyAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_KeyAdapter$vtype	*vtype;
	_jc_java_awt_event_KeyAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_KeyAdapter$vtype _jc_java_awt_event_KeyAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_KeyAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_KeyAdapter$class_object;

#endif	/* _JC_java_awt_event_KeyAdapter_H_ */
